@@ -52,8 +52,8 @@ function(R, L = 0, method = c("simple", "interp", "binomial", "blackscholes"), o
 
     switch(method,
         simple = {
-            numerator = exp(-rf) * mean(max(x - L, 0))
-            denominator = exp(-rf) * mean(max(L - x, 0))
+            numerator = exp(-rf) * mean(pmax(x - L, 0))
+            denominator = exp(-rf) * mean(pmax(L - x, 0))
             omega = numerator/denominator
         },
         binomial = {
@@ -67,6 +67,7 @@ function(R, L = 0, method = c("simple", "interp", "binomial", "blackscholes"), o
         interp = {
 
             # require("Hmisc")
+            stopifnot("package:Hmisc" %in% search() || require("Hmisc",quietly=TRUE))
             a = min(x)
             b = max(x)
 
@@ -93,15 +94,24 @@ function(R, L = 0, method = c("simple", "interp", "binomial", "blackscholes"), o
 ###############################################################################
 # R (http://r-project.org/) Econometrics for Performance and Risk Analysis
 #
-# Copyright (c) 2004-2007 Peter Carl and Brian G. Peterson
+# Copyright (c) 2004-2008 Peter Carl and Brian G. Peterson
 #
 # This library is distributed under the terms of the GNU Public License (GPL)
 # for full details see the file COPYING
 #
-# $Id: Omega.R,v 1.8 2007/03/04 18:37:09 brian Exp $
+# $Id: Omega.R,v 1.11 2008-09-29 13:47:18 brian Exp $
 #
 ###############################################################################
 # $Log: Omega.R,v $
+# Revision 1.11  2008-09-29 13:47:18  brian
+# - fix to use pmax per patch submitted by Ryan Sheftel <at> Malbec Pertners
+#
+# Revision 1.10  2008-06-25 03:50:37  peter
+# - added package test for Hmisc
+#
+# Revision 1.9  2008-06-02 16:05:19  brian
+# - update copyright to 2004-2008
+#
 # Revision 1.8  2007/03/04 18:37:09  brian
 # - update to use switch on method, more efficient
 #
