@@ -1,5 +1,5 @@
 `chart.TimeSeries` <-
-function (R, reference.grid = TRUE, xaxis = TRUE, type = "l", lty = 1, lwd = 1, main = NULL, ylab=NULL, xlab="Date", date.format.in="%Y-%m-%d", date.format = "%m/%y", xlim = NULL, ylim = NULL, event.lines = NULL, event.labels = NULL, period.areas = NULL, event.color = "darkgray", period.color = "lightgray", colorset = (1:12), pch = (1:12), darken = FALSE , legend.loc = NULL, ylog = FALSE, ...)
+function (R, reference.grid = TRUE, xaxis = TRUE, yaxis = TRUE, yaxis.right = FALSE, type = "l", lty = 1, lwd = 1, main = NULL, ylab=NULL, xlab="Date", date.format.in="%Y-%m-%d", date.format = "%m/%y", xlim = NULL, ylim = NULL, event.lines = NULL, event.labels = NULL, period.areas = NULL, event.color = "darkgray", period.color = "lightgray", colorset = (1:12), pch = (1:12), darken = FALSE , legend.loc = NULL, ylog = FALSE, cex.axis=0.8, cex.legend = 0.8, cex.labels = 0.8, ...)
 { # @author Peter Carl
 
     # DESCRIPTION:
@@ -125,7 +125,7 @@ function (R, reference.grid = TRUE, xaxis = TRUE, type = "l", lty = 1, lwd = 1,
 
         abline(v = event.ind, col = event.color)
         if(!is.null(event.labels)) {
-            text(x=event.ind,y=ylim[2], label = event.labels[number.event.labels], offset = .2, pos = 2, cex = 0.7, srt=90, col = event.color)
+            text(x=event.ind,y=ylim[2], label = event.labels[number.event.labels], offset = .2, pos = 2, cex = cex.labels, srt=90, col = event.color)
         }
     }
 
@@ -144,19 +144,23 @@ function (R, reference.grid = TRUE, xaxis = TRUE, type = "l", lty = 1, lwd = 1,
     }
 
     if (xaxis) {
-        axis(1, at = lab.ind, lab=rownames[lab.ind], cex.axis = 0.8, col = elementcolor)
+        axis(1, at = lab.ind, lab=rownames[lab.ind], cex.axis = cex.axis, col = elementcolor)
         title(xlab = xlab)
         # use axis(..., las=3) for vertical labels.
     }
 
     # set up y-axis
-    axis(2, cex.axis = 0.8, col=elementcolor, ylog=ylog)
+    if (yaxis)
+        if(yaxis.right)
+            axis(4, cex.axis = cex.axis, col=elementcolor, ylog=ylog)
+        else
+            axis(2, cex.axis = cex.axis, col=elementcolor, ylog=ylog)
     box(col = elementcolor)
 
     if(!is.null(legend.loc)){
         # There's no good place to put this automatically, except under the graph.
         # That requires a different solution, but here's the quick fix
-        legend(legend.loc, inset = 0.02, text.col = colorset, col = colorset, cex = .8, border.col = elementcolor, lwd = 2, bg = "white", legend = columnnames)
+        legend(legend.loc, inset = 0.02, text.col = colorset, col = colorset, cex = cex.legend, border.col = elementcolor, lty = lty, lwd = 2, bg = "white", legend = columnnames)
     }
 
     # Add the other titles
@@ -170,15 +174,27 @@ function (R, reference.grid = TRUE, xaxis = TRUE, type = "l", lty = 1, lwd = 1,
 ###############################################################################
 # R (http://r-project.org/) Econometrics for Performance and Risk Analysis
 #
-# Copyright (c) 2004-2007 Peter Carl and Brian G. Peterson
+# Copyright (c) 2004-2008 Peter Carl and Brian G. Peterson
 #
 # This library is distributed under the terms of the GNU Public License (GPL)
 # for full details see the file COPYING
 #
-# $Id: chart.TimeSeries.R,v 1.8 2007/11/19 03:42:14 peter Exp $
+# $Id: chart.TimeSeries.R,v 1.12 2008-08-16 03:42:26 peter Exp $
 #
 ###############################################################################
 # $Log: chart.TimeSeries.R,v $
+# Revision 1.12  2008-08-16 03:42:26  peter
+# - added yaxis.right parameter
+#
+# Revision 1.11  2008-06-28 13:55:25  peter
+# - added cex.labels attribute
+#
+# Revision 1.10  2008-06-02 16:05:19  brian
+# - update copyright to 2004-2008
+#
+# Revision 1.9  2008/02/15 04:21:20  peter
+# - added parameters for legend management
+#
 # Revision 1.8  2007/11/19 03:42:14  peter
 # - title will no longer be set to default text, will use column name instead
 #
