@@ -35,6 +35,8 @@ charts.RollingRegression = function (Ra, Rb, width = 12, rf = 0, darken = FALSE,
 
 #    plot.new()
 
+    op <- par(no.readonly=TRUE)
+
     layout(matrix(c(1,2,3)),height=c(1.3,1,1.3),width=1)
 
     par(mar=c(1,4,4,2))
@@ -52,20 +54,27 @@ charts.RollingRegression = function (Ra, Rb, width = 12, rf = 0, darken = FALSE,
 
     chart.RollingRegression(Ra, Rb, width = width, rf = rf, attribute = "R-Squared", darken = darken, main = "", ylab = "R-Squared", event.labels = NULL, ...)
 
+    par(op)
 }
 
 ###############################################################################
 # R (http://r-project.org/) Econometrics for Performance and Risk Analysis
 #
-# Copyright (c) 2004-2007 Peter Carl and Brian G. Peterson
+# Copyright (c) 2004-2008 Peter Carl and Brian G. Peterson
 #
 # This library is distributed under the terms of the GNU Public License (GPL)
 # for full details see the file COPYING
 #
-# $Id: charts.RollingRegression.R,v 1.13 2007/11/19 03:43:12 peter Exp $
+# $Id: charts.RollingRegression.R,v 1.15 2008-06-02 16:05:19 brian Exp $
 #
 ###############################################################################
 # $Log: charts.RollingRegression.R,v $
+# Revision 1.15  2008-06-02 16:05:19  brian
+# - update copyright to 2004-2008
+#
+# Revision 1.14  2008-04-18 03:53:19  peter
+# - added par to reset layout to default
+#
 # Revision 1.13  2007/11/19 03:43:12  peter
 # - removed event.labels from lower charts
 #
